package Language;
use vars qw(%dict);
#
# Translation notes for translators and module writers (if any).
#
# Both dictionary entries and translated messages are sprintf-like 
# formats, which are used as translate($message,@args).
#
# Occurences of '%s' in message denotes places to insert a word
# and '%d' is to insert a number. Other specifiers are ignored.
# Arguments are mostly data labels. The message and each arg are
# looked up in this dictionary, and then combined to form final
# message.
#
# Some messages imply plural form of word, and in languages with
# several noun cases, possibly - other forms of word in depend on
# context. In more complicated cases, a message itself should vary
# in depend of words which are inserted.
#
# Translation module is exact thing to support all such cases.
# Either original or translated message may contain several
# expansions to modify either message text or argument values
# BEFORE they are looked up in dictionary.
#
# Arguments, passed to translation routine expected to be always
# in singular form, lowercased and w/out spaces - as found in
# parser module and config file.
# Exception are 'bytes', 'connections', 'elapsed' etc, which is
# of aggregable data and are always plural or uncountable. To do
# not handle them separately, and to do not use singular forms in
# config parser i just put %S instead of %s where such labels
# expected.
#
# To alter argument value place %[TEXT] or %{EXPR} instead of
# corresponding %s in translation.
# This will replace argument value with given TEXT or value of
# perl-evaluated EXPR.
# Inside TEXT and EXPR, appearences of & and $N are replaced with
# value of corresponding arg, or Nth arg. The $# is total number
# of arguments.
#
# Eggs:
# If ("Total for %s",'date') has to be "Daten Total" in your
# language, and ("Total for %s",'host') to be "Hoste Total",
# entries could be:
#   'Total for %s' => '%[fur-&] Total'
#   'fur-date'     => 'Daten'
#   'fur-host'     => 'Hoste'
# For classic example with "N Bars" to append 's' when N>1:
#   '%d %s'        => '%d %{ ( $1 > 1 ) ? "&s" : "&" }'
# Not classic example with "N Bars" in russian (and probably some
# other slavic languages):
#   '%d %s'        => '%d %{ ( "$1" =~ /(?<!1)1$/ ) ? "&" :
#                            ( "$1" =~ /[2-4]$/ )   ? "of-&" : "of-&s" }'
# this will chose one of 3 forms for 'Bars'.
#
# If message applied to variable number of arguments, some part
# containing '%s' should be repeated for each argument:
# /TEXT/JOIN/ is replaced with repeated TEXT, joned with JOIN, to
# make number of % fit number of arguments.
#
# Eggs:
# translate( '%s by /%s/ and /', foo,bar1,bar2,bar3)
#   returns "foo by bar1 and bar2 and bar3"
# translate( '%s for /%s=%s/, /',foo,bar,bar1,baz,baz1)
#   returns "foo for bar=bar1, baz=baz1"
# Value of TEXT and JOIN may contain %[] or %{} expansions, thus
# u may chose word variation for all arguments in list.
#
# And finally, you may use ${EXPR}, which is simply evaluated and
# inserted into message.
# The returned value of ${EXPR} may contain %[TEXT], %{EXPR}, or
# /TEXT/JOIN/, and also '$N' and '$#'. Note, that it should not
# contain '&', but rather '%s' or '%[TEXT]', since it is inserted
# into text, but not arg value.
#
# Egg, to make comma separated list to end with 'and %s' in case
# when number of args>2:
#   '/%s/, /' => '/%s/, / ${ ($#>2) ? " and %s" : "" }',
#
# This is not simplest way to perform translation, but otherwise
# we had to include all possible combinations of messages with
# all data labels into dictionary and avoid usage of variable
# arg number messages.  Adding parsers with new data labels and
# reports with new messages would became unhandlable.
#
# I think that's enough to make fine translations of wide range
# of messages into many reasonable languages.
# Email me if u disagree or have another ideas.
#
# --
# QMax <qmax@mail.ru>
#

#
# This is template and english dictionary.
# Used to turn data labels into more readable form
# Identical translations are commented out.
#

%dict =(
#    'General'		=> 'General',
#    'Summary'		=> 'Summary',
#    # %s is formatted date of reporting period
#    'Report for %s'	=> 'Report for %s',
#    'Reporting period'	=> 'Reporting period',
#    'Begin'		=> 'Begin',
#    'End'		=> 'End',
#    'Total of days'	=> 'Total of days',
#    'Reporting days'	=> 'Reporting days',
#    'Total'		=> 'Total',
#    # %s is a key of summarized row or column, or 'Reporting period'
#    'Total for %s'	=> 'Total for %s',
    ### page titles
    '/%s/, /'		=> '/%[&s]/, /${ ($#>1)? " and %[&s]" : "" }',
    'by /%s/, /'	=> 'by /%[&s]/, /${ ($#>1) ? " and %[&s]" : "" }',
    ### table title: key,value sequence
#    '/%s:%s/, /'	=> '/%s:%s/, /',
    ### aggregation functions
    'COUNT(%s)'		=> 'Count of %[&s]',
    'SUM(%S)'		=> '${ ("$1" eq "requests") ? "Number" : "Amount" } of %s',
    'MIN(%S)'		=> 'Minimum of %s',
    'MAX(%S)'		=> 'Maximum of %s',
    'AVG(%S)'		=> 'Average of %s',
    'records'		=> 'Records',
#    ### ignore-less, %d is number of ignored rows
#    'More %d skipped'	=> 'More %d skipped',

    #### Copyright infos
#    'generated with &quot;%s&quot;<br>written by %s &lt;<a href="mailto:%s">%s</a>&gt;<br>get the newest version from <a href="%s" target="_blank">%s</a>'=>
#	'generated with &quot;%s&quot;<br>written by %s &lt;<a href="mailto:%s">%s</a>&gt;<br>get the newest version from <a href="%s" target="_blank">%s</a>'=>
#    'report module &quot;%s&quot; written by %s &lt;<a href="mailto:%s">%s</a>&gt;' =>
#	'report module &quot;%s&quot; written by %s &lt;<a href="mailto:%s">%s</a>&gt;' =>

#   #### labels of extra info in parsers
#    'CodeRed attacks'	=> 'CodeRed attacks',
#    'Nimda attacks'	=> 'Nimda attacks',
#    'Search terms used'	=> 'Search terms used',
#    'Total requests'	=> 'Total requests',
#    'Averange requests per day'	=> 'Averange requests per day',

    #### log labels with variations:
    # singular forms, (thatis - as given in parser)
    'browser'		=> 'Browser',
    'bytes'		=> 'Byte',
    'client'		=> 'Client',
    'connections'	=> 'Connections',
    'date'		=> 'Date',
    'destinationport'	=> 'Destination Port',
    'destination'	=> 'Destination',
    'domain'		=> 'Domain',
    'elapsed'		=> 'Elapsed Time',
    'file'		=> 'File',
    'hierarchycode'	=> 'Hierarchy Code',
    'host'		=> 'Host',
    'hour'		=> 'Hour',
    'httpstatus'	=> 'HTTP Status',
    'interface'		=> 'Interface',
    'method'		=> 'Method',
    'mime'		=> 'MIME',
    'month'		=> 'Month',
    'os'		=> 'OS',
    'peer'		=> 'Peer',
    'packetcount'	=> 'Packet Count',
    'protocol'		=> 'Protocol',
    'referer'		=> 'Referer',
    'resultcode'	=> 'Result Code',
    'requests'		=> 'Requests',
    'server'		=> 'Server',
    'sourceport'	=> 'Source Port',
    'source'		=> 'Source',
    'statuse'		=> 'Statuse',
    'tld'		=> 'TLD',
    'user'		=> 'User',
    'virtualhost'	=> 'Virtual Host',
    # plural forms (with 's' appended)
    # bytes, etc fixed back
    'browsers'		=> 'Browsers',
    'bytess'		=> 'Bytes',
    'clients'		=> 'Clients',
    'connectionss'	=> 'Connections',
    'dates'		=> 'Dates',
    'destinationports'	=> 'Destination Ports',
    'destinations'	=> 'Destinations',
    'domains'		=> 'Domains',
    'elapseds'		=> 'Elapsed Time',
    'files'		=> 'Files',
    'hierarchycodes'	=> 'Hierarchy Codes',
    'hosts'		=> 'Hosten',
    'hours'		=> 'Hours',
    'httpstatuss'	=> 'HTTP Statuses',
    'interfaces'	=> 'Interfaces',
    'methods'		=> 'Methods',
    'mimes'		=> 'MIMEs',
    'months'		=> 'Months',
    'oss'		=> 'OSes',
    'peers'		=> 'Peers',
    'packetcounts'	=> 'Packet Count',
    'protocols'		=> 'Protocols',
    'referers'		=> 'Referers',
    'resultcodes'	=> 'Result Codes',
    'requestss'		=> 'Requests',
    'servers'		=> 'Servers',
    'sourceports'	=> 'Source Ports',
    'sources'		=> 'Sources',
    'statuss'		=> 'Statuses',
    'tlds'		=> 'TLDs',
    'users'		=> 'Users',
    'virtualhosts'	=> 'Virtual Hosts',
);

1;
